use std::collections::HashMap;

use axum::async_trait;

use crate::{error::Error, game::PlayerId};

pub mod single_choice;

#[async_trait]
pub trait Question: Send + Sync {
    async fn render_player(&self, player_id: &PlayerId, show_result: bool)
        -> Result<String, Error>;

    async fn handle_answer(
        &mut self,
        player_id: PlayerId,
        values: &HashMap<String, String>,
    ) -> Result<(), Error>;

    async fn has_answered(&self, player_id: &PlayerId) -> Result<bool, Error>;

    async fn answered_correctly(&self, player_id: &PlayerId) -> Result<bool, Error>;

    async fn answer_count(&self) -> Result<u32, Error>;

    async fn render_viewer(&self, show_result: bool) -> Result<String, Error>;
}
